@@ -41,7 +41,11 @@ class ConstraintWithMetadataException(Exception):
         self.actual = check.opt_inst_param(actual, "actual", (dict, list, str, set))
         super(ConstraintWithMetadataException, self).__init__(
             "Violated {} - {}, {} was/were expected, but we received {} which was/were {}".format(
-                constraint_name, constraint_description, expectation, offending, actual,
+                constraint_name,
+                constraint_description,
+                expectation,
+                offending,
+                actual,
             )
         )
 
@@ -92,7 +96,7 @@ class ColumnConstraintViolationException(ConstraintViolationException):
         super(ColumnConstraintViolationException, self).__init__(self.construct_message())
 
     def construct_message(self):
-        base_message = "Violated {constraint_name} ({constraint_description}) for Column Name ({column_name}) ".format(
+        base_message = 'Violated "{constraint_name}" for column "{column_name}" - {constraint_description}'.format(
             constraint_name=self.constraint_name,
             constraint_description=self.constraint_description,
             column_name=self.column_name,
@@ -197,20 +201,20 @@ class ConstraintWithMetadata:
 
 class MultiConstraintWithMetadata(ConstraintWithMetadata):
     """
-        Use this class if you have multiple constraints to check over the entire dataframe
+    Use this class if you have multiple constraints to check over the entire dataframe
 
-        args:
-            description (str): description of the constraint
-            validation_fn_arr(List[Callable[[DataFrame], Tuple[bool, dict[str, Union[dict,list, str, set]]]]]):
-                        a list of the validation functions to run over inputted data
-                        Each function should return a tuple of a boolean for success or failure, and a dict containing
-                        metadata about the test -- this metadata will be passed to the resulting exception if validation
-                        fails.
-            resulting_exception (ConstraintWithMetadataException):  what response a failed typecheck should induce
-            raise_or_typecheck (Optional[bool]): whether to raise an exception (if set to True) or emit a failed typecheck event
-                        (if set to False) when validation fails
-            name (Optional[str]): what to call the constraint, defaults to the class name.
-        """
+    args:
+        description (str): description of the constraint
+        validation_fn_arr(List[Callable[[DataFrame], Tuple[bool, dict[str, Union[dict,list, str, set]]]]]):
+                    a list of the validation functions to run over inputted data
+                    Each function should return a tuple of a boolean for success or failure, and a dict containing
+                    metadata about the test -- this metadata will be passed to the resulting exception if validation
+                    fails.
+        resulting_exception (ConstraintWithMetadataException):  what response a failed typecheck should induce
+        raise_or_typecheck (Optional[bool]): whether to raise an exception (if set to True) or emit a failed typecheck event
+                    (if set to False) when validation fails
+        name (Optional[str]): what to call the constraint, defaults to the class name.
+    """
 
     def __init__(
         self,
@@ -488,23 +492,23 @@ class ColumnConstraintWithMetadata(ConstraintWithMetadata):
 
 class MultiColumnConstraintWithMetadata(ColumnConstraintWithMetadata):
     """
-        This class is useful for constructing more complicated relationships between columns
-        and expectations -- i.e. you want some validations on column A, others on column B, etc.
-        This lets you package up the metadata neatly,
-        and also allows for cases like 'fail if any one of these constraints fails but still run all of them'
+    This class is useful for constructing more complicated relationships between columns
+    and expectations -- i.e. you want some validations on column A, others on column B, etc.
+    This lets you package up the metadata neatly,
+    and also allows for cases like 'fail if any one of these constraints fails but still run all of them'
 
-        Args:
-            description (str): description of the overall set of validations
-            fn_and_columns_dict (Dict[str, List[Callable[[Any], Tuple[bool, dict[str, Union[dict,list, str, set]]]]]):
-                                        while this is a relatively complex type,
-                                        what it amounts to is 'a dict mapping columns to the functions to
-                                        run on them'
-            resulting_exception (type): the response to generate if validation fails. Subclass of
-                                        ConstraintWithMetadataException
-            raise_or_typecheck (Optional[bool]):  whether to raise an exception (true) or a failed typecheck (false)
-            type_for_internal (Optional[type]): what type to use for internal validators.  Subclass of
-                                                ConstraintWithMetadata
-            name (Optional[str]): what to call the constraint, defaults to the class name.
+    Args:
+        description (str): description of the overall set of validations
+        fn_and_columns_dict (Dict[str, List[Callable[[Any], Tuple[bool, dict[str, Union[dict,list, str, set]]]]]):
+                                    while this is a relatively complex type,
+                                    what it amounts to is 'a dict mapping columns to the functions to
+                                    run on them'
+        resulting_exception (type): the response to generate if validation fails. Subclass of
+                                    ConstraintWithMetadataException
+        raise_or_typecheck (Optional[bool]):  whether to raise an exception (true) or a failed typecheck (false)
+        type_for_internal (Optional[type]): what type to use for internal validators.  Subclass of
+                                            ConstraintWithMetadata
+        name (Optional[str]): what to call the constraint, defaults to the class name.
     """
 
     def __init__(
@@ -571,22 +575,22 @@ class MultiColumnConstraintWithMetadata(ColumnConstraintWithMetadata):
 
 class MultiAggregateConstraintWithMetadata(MultiColumnConstraintWithMetadata):
     """
-        This class is similar to multicolumn, but takes in functions that operate on the whole column at once
-        rather than ones that operate on each value --
-        consider this similar to the difference between apply-map and apply aggregate.
+    This class is similar to multicolumn, but takes in functions that operate on the whole column at once
+    rather than ones that operate on each value --
+    consider this similar to the difference between apply-map and apply aggregate.
 
-        Args:
-            description (str): description of the overall set of validations (TODO:  support multiple descriptions)
-            fn_and_columns_dict (Dict[str, List[Callable[[pd.Series], Tuple[bool, dict[str, Union[dict,list, str, set]]]]]):
-                                        while this is a relatively complex type,
-                                        what it amounts to is a dict mapping columns to the functions to
-                                        run on them'
-            resulting_exception (type): the response to generate if validation fails. Subclass of
-                                        ConstraintWithMetadataException
-            raise_or_typecheck (Optional[bool]):  whether to raise an exception (true) or a failed typecheck (false)
-            type_for_internal (Optional[type]): what type to use for internal validators.  Subclass of
-                                                ConstraintWithMetadata
-            name (Optional[str]): what to call the constraint, defaults to the class name.
+    Args:
+        description (str): description of the overall set of validations (TODO:  support multiple descriptions)
+        fn_and_columns_dict (Dict[str, List[Callable[[pd.Series], Tuple[bool, dict[str, Union[dict,list, str, set]]]]]):
+                                    while this is a relatively complex type,
+                                    what it amounts to is a dict mapping columns to the functions to
+                                    run on them'
+        resulting_exception (type): the response to generate if validation fails. Subclass of
+                                    ConstraintWithMetadataException
+        raise_or_typecheck (Optional[bool]):  whether to raise an exception (true) or a failed typecheck (false)
+        type_for_internal (Optional[type]): what type to use for internal validators.  Subclass of
+                                            ConstraintWithMetadata
+        name (Optional[str]): what to call the constraint, defaults to the class name.
     """
 
     def __init__(
@@ -632,20 +636,21 @@ def all_unique_validator(column, ignore_missing_vals=False):
     Example:
         .. code-block:: python
             aggregate_validator = MultiAggregateConstraintWithMetadata(
-            "confirms all values are unique",
-            {'bar': [all_unique_validator]},
-            ConstraintWithMetadataException,
-            raise_or_typecheck=False,
+                "confirms all values are unique",
+                {'bar': [all_unique_validator]},
+                ConstraintWithMetadataException,
+                raise_or_typecheck=False,
             )
             ntype = create_structured_dataframe_type(
-            "NumericType",
-            columns_aggregate_validator=aggregate_validator
+                "NumericType",
+                columns_aggregate_validator=aggregate_validator
             )
-            @solid(output_defs=[OutputDefinition(name='basic_dataframe', dagster_type=ntype)])
+            @op(out={'basic_dataframe': Out(dagster_type=ntype)})
             def create_dataframe(_):
                 yield Output(
-                DataFrame({'foo': [1, 2, 3], 'bar': [9, 10, 10]}), output_name='basic_dataframe',
-            )
+                    DataFrame({'foo': [1, 2, 3], 'bar': [9, 10, 10]}),
+                    output_name='basic_dataframe',
+                )
             #will fail with
             metadata['offending'] == {'bar': {'all_unique_validator': 'a violation'}}
             metadata['actual'] == {'bar': {'all_unique_validator': [10.0]}}
@@ -697,20 +702,21 @@ def column_range_validation_factory(minim=None, maxim=None, ignore_missing_vals=
         .. code-block:: python
             in_range_validator = column_range_validation_factory(1, 3, ignore_missing_vals=True)
             column_validator = MultiColumnConstraintWithMetadata(
-                            "confirms values are numbers in a range",
-                            {'foo': [in_range_validator]},
-                            ColumnWithMetadataException,
-                            raise_or_typecheck=False,
-                        )
-            ntype = create_structured_dataframe_type(
-            "NumericType",
-            columns_validator=column_validator
+                "confirms values are numbers in a range",
+                {'foo': [in_range_validator]},
+                ColumnWithMetadataException,
+                raise_or_typecheck=False,
             )
-            @solid(output_defs=[OutputDefinition(name='basic_dataframe', dagster_type=ntype)])
+            ntype = create_structured_dataframe_type(
+                "NumericType",
+                columns_validator=column_validator
+            )
+            @op(out={'basic_dataframe': Out(dagster_type=ntype)})
             def create_dataframe(_):
                 yield Output(
-                DataFrame({'foo': [1, 2, 7], 'bar': [9, 10, 10]}), output_name='basic_dataframe',
-            )
+                    DataFrame({'foo': [1, 2, 7], 'bar': [9, 10, 10]}),
+                    output_name='basic_dataframe',
+                )
             #will fail with
             metadata['offending'] == {'foo': {'in_range_validation_fn': ['row 2']}}
             metadata['actual'] == {'foo': {'in_range_validation_fn': [7]}}
@@ -759,20 +765,21 @@ def categorical_column_validator_factory(categories, ignore_missing_vals=False):
         .. code-block:: python
             categorical_validation_fn = categorical_column_validator_factory([1, 2])
             column_validator = MultiColumnConstraintWithMetadata(
-                            "confirms values are numbers in a range",
-                            {'foo': [categorical_validation_fn]},
-                            ColumnWithMetadataException,
-                            raise_or_typecheck=False,
-                        )
-            ntype = create_structured_dataframe_type(
-            "NumericType",
-            columns_validator=column_validator
+                "confirms values are numbers in a range",
+                {'foo': [categorical_validation_fn]},
+                ColumnWithMetadataException,
+                raise_or_typecheck=False,
             )
-            @solid(output_defs=[OutputDefinition(name='basic_dataframe', dagster_type=ntype)])
+            ntype = create_structured_dataframe_type(
+                "NumericType",
+                columns_validator=column_validator
+            )
+            @op(out={'basic_dataframe': Out(dagster_type=ntype)})
             def create_dataframe(_):
                 yield Output(
-                DataFrame({'foo': [1, 2, 7], 'bar': [9, 10, 10]}), output_name='basic_dataframe',
-            )
+                    DataFrame({'foo': [1, 2, 7], 'bar': [9, 10, 10]}),
+                    output_name='basic_dataframe',
+                )
             #will fail with
             metadata['offending'] == {'foo': {'categorical_validation_fn': ['row 2']}}
             metadata['actual'] == {'foo': {'categorical_validation_fn': [7]}}
@@ -786,8 +793,8 @@ def categorical_column_validator_factory(categories, ignore_missing_vals=False):
             return True, {}
         return (x in categories), {}
 
-    categorical_validation_fn.__doc__ = "checks whether values are within this set of values: {}".format(
-        categories
+    categorical_validation_fn.__doc__ = (
+        "checks whether values are within this set of values: {}".format(categories)
     )
     if ignore_missing_vals:
         categorical_validation_fn.__doc__ += ", ignoring nulls"
@@ -813,20 +820,21 @@ def dtype_in_set_validation_factory(datatypes, ignore_missing_vals=False):
         .. code-block:: python
             dtype_is_num_validator = dtype_in_set_validation_factory((int, float, int64, float64))
             column_validator = MultiColumnConstraintWithMetadata(
-            "confirms values are numbers in a range",
-            {'foo': [dtype_is_num_validator]},
-            ColumnWithMetadataException,
-            raise_or_typecheck=False,
+                "confirms values are numbers in a range",
+                {'foo': [dtype_is_num_validator]},
+                ColumnWithMetadataException,
+                raise_or_typecheck=False,
             )
             ntype = create_structured_dataframe_type(
-            "NumericType",
-            columns_validator=column_validator
+                "NumericType",
+                columns_validator=column_validator
             )
-            @solid(output_defs=[OutputDefinition(name='basic_dataframe', dagster_type=ntype)])
+            @op(out={'basic_dataframe': Out(dagster_type=ntype)})
             def create_dataframe(_):
                 yield Output(
-                DataFrame({'foo': [1, 'a', 7], 'bar': [9, 10, 10]}), output_name='basic_dataframe',
-            )
+                    DataFrame({'foo': [1, 'a', 7], 'bar': [9, 10, 10]}),
+                    output_name='basic_dataframe',
+                )
             #will fail with
             metadata['offending'] == {'foo': {'categorical_validation_fn': ['row 1']}}
             metadata['actual'] == {'foo': {'categorical_validation_fn': ['a']}}
@@ -893,7 +901,7 @@ class ColumnConstraint(Constraint):
 
 class ColumnDTypeFnConstraint(ColumnConstraint):
     """
-    A column constraint that applies a pandas dtype validation function to a columns dtypes.
+    A column constraint that applies a pandas dtype validation function to a columns dtype.
 
     Args:
         type_fn (Callable[[Set[str]], bool]): This is a function that takes the pandas columns dtypes and
@@ -902,21 +910,17 @@ class ColumnDTypeFnConstraint(ColumnConstraint):
 
     def __init__(self, type_fn):
         self.type_fn = check.callable_param(type_fn, "type_fn")
-        description = "{fn} must evaluate to True for column dtypes".format(
-            fn=self.type_fn.__name__
-        )
+        description = f'Dtype must satisfy "{self.type_fn.__name__}"'
         super(ColumnDTypeFnConstraint, self).__init__(
             error_description=description, markdown_description=description
         )
 
     def validate(self, dataframe, column_name):
-        received_dtypes = dataframe[column_name].dtype
-        if not self.type_fn(received_dtypes):
+        column_dtype = dataframe[column_name].dtype
+        if not self.type_fn(column_dtype):
             raise ColumnConstraintViolationException(
                 constraint_name=self.name,
-                constraint_description="{base_error_message}. Dtypes received: {received_dtypes}.".format(
-                    base_error_message=self.error_description, received_dtypes=received_dtypes
-                ),
+                constraint_description=f'{self.error_description}, but was "{column_dtype}"',
                 column_name=column_name,
             )
 
